!!$=head1 NAME
!!$
!!$Autocorr - compute autocorrelation for helix filters
!!$
!!$=head1 SYNOPSIS
!!$
!!$Autocorr < filt.H  > autocorr.H
!!$
!!$=head1 DESCRIPTION
!!$
!!$Reads a helix filter. Outputs the positive lag of its 
!!$autocorrelation (no space wasted). 
!!$
!!$=head1 PARAMETERS
!!$
!!$=over 3
!!$
!!$=item from/to history
!!$
!!$B<integer> I<n1> - filter size
!!$
!!$B<integer array> I<lag> - comma-separated list of filter lags
!!$
!!$B<real> I<a0>=1 - zero-lag coefficient
!!$
!!$=back
!!$
!!$=head1 EXAMPLES
!!$
!!$F<gee/hlx/helicon90/>
!!$
!!$=head1 MODULES
!!$
!!$F<helix.r90>, F<autocorr.r90>
!!$
!!$=head1 SEA ALSO
!!$
!!$L<Helicon>, L<Wilson>, L<Pef>
!!$
!!$=cut
!%
program Auto
  use sep
  use helix
  use autocorr

  implicit none
  integer       :: i, na
  real          :: s0, a0
  type( filter) :: ss, aa

  call sep_init (SOURCE)
  call from_history (na)
  call allocatehelix (aa, na)
  call from_history ("lag", aa%lag, (/ (i, i = 1, na) /))
  call from_history ("a0", a0, 1.)
  call sep_read (aa%flt)
  ss = autocorr1 (aa, s0, a0)
  call to_history ("a0", s0*0.5)
  call to_history ("n1",size(ss%lag))
  call to_history ("lag",ss%lag)
  call sep_write (ss%flt)

  call sep_close ()
  call deallocatehelix (ss)
  call deallocatehelix (aa)
  call exit (0)
end program Auto
