!!$=head1 NAME
!!$
!!$Autocorr - compute autocorrelation for helix filters
!!$
!!$=head1 SYNOPSIS
!!$
!!$Autocorr < filt.H  > autocorr.H
!!$
!!$=head1 DESCRIPTION
!!$
!!$Reads a helix filter. Outputs the positive lag of its 
!!$autocorrelation (no space wasted). 
!!$
!!$=head1 PARAMETERS
!!$
!!$=over 3
!!$
!!$=item from/to history
!!$
!!$B<integer> I<n1> - filter size
!!$
!!$B<integer array> I<lag> - comma-separated list of filter lags
!!$
!!$B<real> I<a0>=1 - zero-lag coefficient
!!$
!!$=back
!!$
!!$=head1 EXAMPLES
!!$
!!$F<gee/hlx/helicon90/>
!!$
!!$=head1 MODULES
!!$
!!$F<helix.r90>, F<autocorr.r90>
!!$
!!$=head1 SEA ALSO
!!$
!!$L<Helicon>, L<Wilson>, L<Pef>
!!$
!!$=cut
!%
program Min_phase
  use sep
  use helix
  use wilson
  use autocorr

  implicit none
  integer       :: i, na,n1,niter
  real          :: s0, a0,m0,eps
  type( filter) :: ss, aa,mm

  call sep_init (SOURCE)
 ! call from_history ("n1",na)
  call from_history (na) 
  call allocatehelix (aa, na)
  call from_history ("lag", aa%lag, (/ (i, i = 1, na) /))
  call from_history ("a0", a0, 1.)
  call from_history("n",n1,400)
 call from_param("eps",eps,.00001)
call from_param("niter",niter,100)
  write(0,*) 'n1',n1,'a0',a0
  call sep_read (aa%flt)
mm=aa
write(0,*) 'eps',eps,'niter',niter

 ! ss = autocorr1 (aa, s0, -.6+a0)
 ss = autocorr1 (aa, s0, 1.)
write(0,*) 's0',s0
write(0,*) 'mm%flt',mm%flt
mm%flt=0.
  call wilson_init(10*n1)
  call wilson_factor(niter,s0+eps,ss,m0,mm)
write(0,*) 'm0',m0
write(0,*) 'mm%flt',mm%flt
  call to_history ("a0", m0)  !*0.5)
  call to_history ("n1",size(mm%lag))
  call to_history ("lag",mm%lag)
  call sep_write (mm%flt)

  call sep_close ()
!  call deallocatehelix (ss)
!  call deallocatehelix (mm)
!  call deallocatehelix (aa)
  call exit (0)
end program Min_phase
