! ----------------------------------------
!  Suspect.f90 - Created by Morgan Brown
!           Mon Jan 29 11:03:23 2001.
! ----------------------------------------
!       Usage: < triplets.H Suspect.x [mdz=infinity  mdr=infinity] > quads.H
!  Parameters: 	mdz is the maximum z jump to define a spike.
!               mdr is the maximum r jump to define a new track.
!               w(i)  = 0  means data point is without suspicion.
!               w(i) += 1  means data point abuts a spike.
!               w(i) += 2  means data point is a spike.
!               w(i) += 4  means data point is at a boundary in (x,y) plane.
!               Caution, most edges are also counted as spikes
! Description:  Append a fourth column to matrix with measure of suspicion.
! ----------------------------------------
program Suspect

use sep

implicit none

integer                           :: ndat, ntrk, id
real                              :: mdr, mdz, edges, spikes
real, dimension(:),   allocatable :: dr, dz, w
real, dimension(:,:), allocatable :: xyz, xyzw

call sep_init(SOURCE)

call from_history( 'n1', ndat)
call from_history( 'n2', ntrk)
if( ntrk /= 3) then
  write(0,*) 'n2 of input file = ',ntrk,', must = 3!'
  call exit(0)
end if
call from_param( 'mdz', mdz)
call from_param( 'mdr', mdr)
call to_history( 'n1', ndat)
call to_history( 'n2', 4)
call sep_close()

allocate( xyz(ndat,3), xyzw(ndat,4), dr( ndat), dz(ndat), w(ndat) )

call sep_read( xyz) 

w = 0.0;  dr = 0.0;  dz = 0.0;

do id = 2,ndat
	dr(id) = sqrt( (xyz(id,1) - xyz(id-1,1))**2 + (xyz(id,2)-xyz(id-1,2))**2   )
	dz(id) = abs(   xyz(id,3) - xyz(id-1,3)  ) 
end do

w(1) = 1.;  w(ndat) = 1.
w(2) = 1.;  w(ndat-1) = 1.

do id=3,ndat-2 
	if( dz(id) > mdz) then
		w(id) = 1;  w(id-1) = 1;  w(id+1) = 1;  w(id-2) = 1;  w(id+2) = 1
	end if

	if( dr(id) > mdr) then
		w(id) = 1;  w(id-1) = 1;  w(id+1) = 1;  w(id-2) = 1;  w(id+2) = 1
	end if
end do

xyzw(:,1:3) = xyz
xyzw(:,4)   = w

call sep_write( xyzw)

deallocate( xyz, xyzw, dr, dz, w )

call exit(0)

end program Suspect
